Method: AIXM::Component::Runway::Direction#threshold_xy

Defined in:
lib/aixm/component/runway.rb

#threshold_xyAIXM::XY

Returns displaced threshold if any or edge of runway otherwise.

Returns:

  • (AIXM::XY)

    displaced threshold if any or edge of runway otherwise



360
361
362
# File 'lib/aixm/component/runway.rb', line 360

def threshold_xy
  displaced_threshold_xy || xy
end